@@ -1843,7 +1843,8 @@ mod test {
                                                 query: None,
                                                 fragment: None,
                                             },
-                                            path: "/foo/bar",
+                                            install_path: "/foo/bar",
+                                            lock_path: "/foo/bar",
                                             editable: true,
                                         },
                                     ),
