@@ -8,7 +8,9 @@ pub use manifest::Manifest;
 pub use options::{Options, OptionsBuilder};
 pub use preferences::{Preference, PreferenceError};
 pub use prerelease_mode::PreReleaseMode;
+pub use pubgrub::{PubGrubSpecifier, PubGrubSpecifierError};
 pub use python_requirement::PythonRequirement;
+pub use requires_python::{RequiresPython, RequiresPythonError};
 pub use resolution::{AnnotationStyle, DisplayResolutionGraph, ResolutionGraph};
 pub use resolution_mode::ResolutionMode;
 pub use resolver::{
@@ -38,6 +40,7 @@ mod prerelease_mode;
 mod pubgrub;
 mod python_requirement;
 mod redirect;
+mod requires_python;
 mod resolution;
 mod resolution_mode;
 mod resolver;
