@@ -4,13 +4,14 @@ use either::Either;
 use itertools::Itertools;
 use pubgrub::range::Range;
 use rustc_hash::FxHashSet;
-use same_file::is_same_file;
 use tracing::warn;
 
 use distribution_types::Verbatim;
 use pep440_rs::Version;
 use pep508_rs::MarkerEnvironment;
-use pypi_types::{ParsedUrl, Requirement, RequirementSource, VerbatimParsedUrl};
+use pypi_types::{
+    ParsedArchiveUrl, ParsedGitUrl, ParsedPathUrl, ParsedUrl, Requirement, RequirementSource,
+};
 use uv_configuration::{Constraints, Overrides};
 use uv_git::GitResolver;
 use uv_normalize::{ExtraName, GroupName, PackageName};
@@ -258,7 +259,11 @@ impl PubGrubRequirement {
                     version,
                 })
             }
-            RequirementSource::Url { url, .. } => {
+            RequirementSource::Url {
+                subdirectory,
+                location,
+                url,
+            } => {
                 let Some(expected) = urls.get(&requirement.name) else {
                     return Err(ResolveError::DisallowedUrl(
                         requirement.name.clone(),
@@ -266,7 +271,11 @@ impl PubGrubRequirement {
                     ));
                 };
 
-                if !Urls::is_allowed(&expected.verbatim, url, git) {
+                let parsed_url = ParsedUrl::Archive(ParsedArchiveUrl::from_source(
+                    location.clone(),
+                    subdirectory.clone(),
+                ));
+                if !Urls::same_resource(&expected.parsed_url, &parsed_url, git) {
                     return Err(ResolveError::ConflictingUrlsTransitive(
                         requirement.name.clone(),
                         expected.verbatim.verbatim().to_string(),
@@ -284,7 +293,13 @@ impl PubGrubRequirement {
                     version: Range::full(),
                 })
             }
-            RequirementSource::Git { url, .. } => {
+            RequirementSource::Git {
+                repository,
+                reference,
+                precise,
+                url,
+                subdirectory,
+            } => {
                 let Some(expected) = urls.get(&requirement.name) else {
                     return Err(ResolveError::DisallowedUrl(
                         requirement.name.clone(),
@@ -292,7 +307,13 @@ impl PubGrubRequirement {
                     ));
                 };
 
-                if !Urls::is_allowed(&expected.verbatim, url, git) {
+                let parsed_url = ParsedUrl::Git(ParsedGitUrl::from_source(
+                    repository.clone(),
+                    reference.clone(),
+                    *precise,
+                    subdirectory.clone(),
+                ));
+                if !Urls::same_resource(&expected.parsed_url, &parsed_url, git) {
                     return Err(ResolveError::ConflictingUrlsTransitive(
                         requirement.name.clone(),
                         expected.verbatim.verbatim().to_string(),
@@ -310,7 +331,12 @@ impl PubGrubRequirement {
                     version: Range::full(),
                 })
             }
-            RequirementSource::Path { url, path, .. } => {
+            RequirementSource::Path {
+                editable,
+                url,
+                install_path,
+                lock_path,
+            } => {
                 let Some(expected) = urls.get(&requirement.name) else {
                     return Err(ResolveError::DisallowedUrl(
                         requirement.name.clone(),
@@ -318,22 +344,13 @@ impl PubGrubRequirement {
                     ));
                 };
 
-                let mut is_allowed = Urls::is_allowed(&expected.verbatim, url, git);
-                if !is_allowed {
-                    if let VerbatimParsedUrl {
-                        parsed_url: ParsedUrl::Path(previous_path),
-                        ..
-                    } = &expected
-                    {
-                        // On Windows, we can have two versions of the same path, e.g.
-                        // `C:\Users\KONSTA~1` and `C:\Users\Konstantin`.
-                        if is_same_file(path, &previous_path.path).unwrap_or(false) {
-                            is_allowed = true;
-                        }
-                    }
-                }
-
-                if !is_allowed {
+                let parsed_url = ParsedUrl::Path(ParsedPathUrl::from_source(
+                    install_path.clone(),
+                    lock_path.clone(),
+                    *editable,
+                    url.to_url(),
+                ));
+                if !Urls::same_resource(&expected.parsed_url, &parsed_url, git) {
                     return Err(ResolveError::ConflictingUrlsTransitive(
                         requirement.name.clone(),
                         expected.verbatim.verbatim().to_string(),
