@@ -476,6 +476,11 @@ impl PubGrubReportFormatter<'_> {
                                 Some(UnavailablePackage::Offline) => {
                                     hints.insert(PubGrubHint::Offline);
                                 }
+                                Some(UnavailablePackage::MissingMetadata) => {
+                                    hints.insert(PubGrubHint::MissingPackageMetadata {
+                                        package: package.clone(),
+                                    });
+                                }
                                 Some(UnavailablePackage::InvalidMetadata(reason)) => {
                                     hints.insert(PubGrubHint::InvalidPackageMetadata {
                                         package: package.clone(),
@@ -500,6 +505,12 @@ impl PubGrubReportFormatter<'_> {
                                             IncompletePackage::Offline => {
                                                 hints.insert(PubGrubHint::Offline);
                                             }
+                                            IncompletePackage::MissingMetadata => {
+                                                hints.insert(PubGrubHint::MissingVersionMetadata {
+                                                    package: package.clone(),
+                                                    version: version.clone(),
+                                                });
+                                            }
                                             IncompletePackage::InvalidMetadata(reason) => {
                                                 hints.insert(PubGrubHint::InvalidVersionMetadata {
                                                     package: package.clone(),
@@ -601,6 +612,8 @@ pub(crate) enum PubGrubHint {
     NoIndex,
     /// A package was not found in the registry, but network access was disabled.
     Offline,
+    /// Metadata for a package could not be found.
+    MissingPackageMetadata { package: PubGrubPackage },
     /// Metadata for a package could not be parsed.
     InvalidPackageMetadata {
         package: PubGrubPackage,
@@ -613,6 +626,12 @@ pub(crate) enum PubGrubHint {
         #[derivative(PartialEq = "ignore", Hash = "ignore")]
         reason: String,
     },
+    /// Metadata for a package version could not be found.
+    MissingVersionMetadata {
+        package: PubGrubPackage,
+        #[derivative(PartialEq = "ignore", Hash = "ignore")]
+        version: Version,
+    },
     /// Metadata for a package version could not be parsed.
     InvalidVersionMetadata {
         package: PubGrubPackage,
@@ -689,6 +708,15 @@ impl std::fmt::Display for PubGrubHint {
                     ":".bold(),
                 )
             }
+            Self::MissingPackageMetadata { package } => {
+                write!(
+                    f,
+                    "{}{} Metadata for {} could not be found, as the wheel is missing a `METADATA` file",
+                    "hint".bold().cyan(),
+                    ":".bold(),
+                    package.bold()
+                )
+            }
             Self::InvalidPackageMetadata { package, reason } => {
                 write!(
                     f,
@@ -709,6 +737,16 @@ impl std::fmt::Display for PubGrubHint {
                     textwrap::indent(reason, "  ")
                 )
             }
+            Self::MissingVersionMetadata { package, version } => {
+                write!(
+                    f,
+                    "{}{} Metadata for {}=={} could not be found, as the wheel is missing a `METADATA` file",
+                    "hint".bold().cyan(),
+                    ":".bold(),
+                    package.bold(),
+                    version.bold(),
+                )
+            }
             Self::InvalidVersionMetadata {
                 package,
                 version,
