@@ -11,17 +11,18 @@ use distribution_types::{
 };
 use pep440_rs::{Version, VersionSpecifier};
 use pep508_rs::{MarkerEnvironment, MarkerTree};
-use pypi_types::{ParsedUrlError, Requirement, Yanked};
+use pypi_types::{ParsedUrlError, Yanked};
 use uv_git::GitResolver;
-use uv_normalize::{ExtraName, PackageName};
+use uv_normalize::{ExtraName, GroupName, PackageName};
 
 use crate::preferences::Preferences;
-use crate::pubgrub::{PubGrubDistribution, PubGrubPackageInner};
+use crate::pubgrub::PubGrubDistribution;
+use crate::python_requirement::PythonTarget;
 use crate::redirect::url_to_precise;
 use crate::resolution::AnnotatedDist;
-use crate::resolver::Resolution;
+use crate::resolver::{Resolution, ResolutionPackage};
 use crate::{
-    lock, InMemoryIndex, Lock, LockError, Manifest, MetadataResponse, ResolveError,
+    InMemoryIndex, Manifest, MetadataResponse, PythonRequirement, RequiresPython, ResolveError,
     VersionsResponse,
 };
 
@@ -30,248 +31,251 @@ use crate::{
 #[derive(Debug)]
 pub struct ResolutionGraph {
     /// The underlying graph.
-    pub(crate) petgraph: Graph<AnnotatedDist, Version, Directed>,
+    pub(crate) petgraph: Graph<AnnotatedDist, Option<MarkerTree>, Directed>,
+    /// The range of supported Python versions.
+    pub(crate) requires_python: Option<RequiresPython>,
     /// Any diagnostics that were encountered while building the graph.
     pub(crate) diagnostics: Vec<ResolutionDiagnostic>,
 }
 
+type NodeKey<'a> = (
+    &'a PackageName,
+    &'a Version,
+    Option<&'a ExtraName>,
+    Option<&'a GroupName>,
+);
+
 impl ResolutionGraph {
     /// Create a new graph from the resolved PubGrub state.
-    #[allow(clippy::too_many_arguments)]
     pub(crate) fn from_state(
         index: &InMemoryIndex,
         preferences: &Preferences,
         git: &GitResolver,
+        python: &PythonRequirement,
         resolution: Resolution,
     ) -> anyhow::Result<Self, ResolveError> {
-        // Collect all marker expressions from relevant pubgrub packages.
-        let mut markers: FxHashMap<(&PackageName, &Version, &Option<ExtraName>), MarkerTree> =
-            FxHashMap::default();
-        for (package, versions) in &resolution.packages {
-            if let PubGrubPackageInner::Package {
-                name,
-                marker: Some(marker),
-                extra,
-                ..
-            } = &**package
-            {
-                for version in versions {
-                    markers
-                        .entry((name, version, extra))
-                        .or_insert_with(|| MarkerTree::Or(vec![]))
-                        .or(marker.clone());
-                }
-            }
-        }
-
-        // Add every package to the graph.
-        let mut petgraph: Graph<AnnotatedDist, Version, Directed> =
+        let mut petgraph: Graph<AnnotatedDist, Option<MarkerTree>, Directed> =
             Graph::with_capacity(resolution.packages.len(), resolution.packages.len());
-        let mut inverse: FxHashMap<(&PackageName, &Version, &Option<ExtraName>), NodeIndex<u32>> =
-            FxHashMap::with_capacity_and_hasher(
-                resolution.packages.len(),
-                BuildHasherDefault::default(),
-            );
+        let mut inverse: FxHashMap<NodeKey, NodeIndex<u32>> = FxHashMap::with_capacity_and_hasher(
+            resolution.packages.len(),
+            BuildHasherDefault::default(),
+        );
         let mut diagnostics = Vec::new();
 
+        // Add every package to the graph.
         for (package, versions) in &resolution.packages {
+            let ResolutionPackage {
+                name,
+                extra,
+                dev,
+                url,
+            } = &package;
+
             for version in versions {
-                match &**package {
-                    PubGrubPackageInner::Package {
-                        name,
-                        extra,
-                        marker: None,
-                        url: None,
-                    } => {
-                        // Create the distribution.
-                        let dist = resolution
-                            .pins
-                            .get(name, version)
-                            .expect("Every package should be pinned")
-                            .clone();
+                // Map the package to a distribution.
+                let (dist, hashes, metadata) = if let Some(url) = url {
+                    // Create the distribution.
+                    let dist = Dist::from_url(name.clone(), url_to_precise(url.clone(), git))?;
 
-                        // Track yanks for any registry distributions.
-                        match dist.yanked() {
-                            None | Some(Yanked::Bool(false)) => {}
-                            Some(Yanked::Bool(true)) => {
-                                diagnostics.push(ResolutionDiagnostic::YankedVersion {
-                                    dist: dist.clone(),
-                                    reason: None,
-                                });
-                            }
-                            Some(Yanked::Reason(reason)) => {
-                                diagnostics.push(ResolutionDiagnostic::YankedVersion {
-                                    dist: dist.clone(),
-                                    reason: Some(reason.clone()),
-                                });
-                            }
-                        }
-
-                        // Extract the hashes, preserving those that were already present in the
-                        // lockfile if necessary.
-                        let hashes = if let Some(digests) = preferences
-                            .match_hashes(name, version)
-                            .filter(|digests| !digests.is_empty())
-                        {
-                            digests.to_vec()
-                        } else if let Some(versions_response) = index.packages().get(name) {
-                            if let VersionsResponse::Found(ref version_maps) = *versions_response {
-                                version_maps
-                                    .iter()
-                                    .find_map(|version_map| version_map.hashes(version))
-                                    .map(|mut digests| {
-                                        digests.sort_unstable();
-                                        digests
-                                    })
-                                    .unwrap_or_default()
-                            } else {
-                                vec![]
-                            }
+                    // Extract the hashes, preserving those that were already present in the
+                    // lockfile if necessary.
+                    let hashes = if let Some(digests) = preferences
+                        .match_hashes(name, version)
+                        .filter(|digests| !digests.is_empty())
+                    {
+                        digests.to_vec()
+                    } else if let Some(metadata_response) =
+                        index.distributions().get(&dist.version_id())
+                    {
+                        if let MetadataResponse::Found(ref archive) = *metadata_response {
+                            let mut digests = archive.hashes.clone();
+                            digests.sort_unstable();
+                            digests
                         } else {
                             vec![]
-                        };
+                        }
+                    } else {
+                        vec![]
+                    };
 
-                        // Extract the metadata.
-                        let metadata = {
-                            let dist = PubGrubDistribution::from_registry(name, version);
+                    // Extract the metadata.
+                    let metadata = {
+                        let dist = PubGrubDistribution::from_url(name, url);
 
-                            let response = index
-                                .distributions()
-                                .get(&dist.version_id())
-                                .unwrap_or_else(|| {
-                                    panic!(
-                                        "Every package should have metadata: {:?}",
-                                        dist.version_id()
-                                    )
-                                });
-
-                            let MetadataResponse::Found(archive) = &*response else {
+                        let response = index
+                            .distributions()
+                            .get(&dist.version_id())
+                            .unwrap_or_else(|| {
                                 panic!(
                                     "Every package should have metadata: {:?}",
                                     dist.version_id()
                                 )
-                            };
+                            });
 
-                            archive.metadata.clone()
+                        let MetadataResponse::Found(archive) = &*response else {
+                            panic!(
+                                "Every package should have metadata: {:?}",
+                                dist.version_id()
+                            )
                         };
 
-                        // Validate the extra.
-                        if let Some(extra) = extra {
-                            if !metadata.provides_extras.contains(extra) {
-                                diagnostics.push(ResolutionDiagnostic::MissingExtra {
-                                    dist: dist.clone(),
-                                    extra: extra.clone(),
-                                });
-                            }
-                        }
-                        // Extract the markers.
-                        let marker = markers.get(&(name, version, extra)).cloned();
+                        archive.metadata.clone()
+                    };
 
-                        // Add the distribution to the graph.
-                        let index = petgraph.add_node(AnnotatedDist {
-                            dist,
-                            extra: extra.clone(),
-                            marker,
-                            hashes,
-                            metadata,
-                        });
-                        inverse.insert((name, version, extra), index);
+                    (dist.into(), hashes, metadata)
+                } else {
+                    let dist = resolution
+                        .pins
+                        .get(name, version)
+                        .expect("Every package should be pinned")
+                        .clone();
+
+                    // Track yanks for any registry distributions.
+                    match dist.yanked() {
+                        None | Some(Yanked::Bool(false)) => {}
+                        Some(Yanked::Bool(true)) => {
+                            diagnostics.push(ResolutionDiagnostic::YankedVersion {
+                                dist: dist.clone(),
+                                reason: None,
+                            });
+                        }
+                        Some(Yanked::Reason(reason)) => {
+                            diagnostics.push(ResolutionDiagnostic::YankedVersion {
+                                dist: dist.clone(),
+                                reason: Some(reason.clone()),
+                            });
+                        }
                     }
 
-                    PubGrubPackageInner::Package {
-                        name,
-                        extra,
-                        marker: None,
-                        url: Some(url),
-                    } => {
-                        // Create the distribution.
-                        let dist = Dist::from_url(name.clone(), url_to_precise(url.clone(), git))?;
-
-                        // Extract the hashes, preserving those that were already present in the
-                        // lockfile if necessary.
-                        let hashes = if let Some(digests) = preferences
-                            .match_hashes(name, version)
-                            .filter(|digests| !digests.is_empty())
-                        {
-                            digests.to_vec()
-                        } else if let Some(metadata_response) =
-                            index.distributions().get(&dist.version_id())
-                        {
-                            if let MetadataResponse::Found(ref archive) = *metadata_response {
-                                let mut digests = archive.hashes.clone();
-                                digests.sort_unstable();
-                                digests
-                            } else {
-                                vec![]
-                            }
+                    // Extract the hashes, preserving those that were already present in the
+                    // lockfile if necessary.
+                    let hashes = if let Some(digests) = preferences
+                        .match_hashes(name, version)
+                        .filter(|digests| !digests.is_empty())
+                    {
+                        digests.to_vec()
+                    } else if let Some(versions_response) = index.packages().get(name) {
+                        if let VersionsResponse::Found(ref version_maps) = *versions_response {
+                            version_maps
+                                .iter()
+                                .find_map(|version_map| version_map.hashes(version))
+                                .map(|mut digests| {
+                                    digests.sort_unstable();
+                                    digests
+                                })
+                                .unwrap_or_default()
                         } else {
                             vec![]
-                        };
+                        }
+                    } else {
+                        vec![]
+                    };
 
-                        // Extract the metadata.
-                        let metadata = {
-                            let dist = PubGrubDistribution::from_url(name, url);
+                    // Extract the metadata.
+                    let metadata = {
+                        let dist = PubGrubDistribution::from_registry(name, version);
 
-                            let response = index
-                                .distributions()
-                                .get(&dist.version_id())
-                                .unwrap_or_else(|| {
-                                    panic!(
-                                        "Every package should have metadata: {:?}",
-                                        dist.version_id()
-                                    )
-                                });
-
-                            let MetadataResponse::Found(archive) = &*response else {
+                        let response = index
+                            .distributions()
+                            .get(&dist.version_id())
+                            .unwrap_or_else(|| {
                                 panic!(
                                     "Every package should have metadata: {:?}",
                                     dist.version_id()
                                 )
-                            };
+                            });
 
-                            archive.metadata.clone()
+                        let MetadataResponse::Found(archive) = &*response else {
+                            panic!(
+                                "Every package should have metadata: {:?}",
+                                dist.version_id()
+                            )
                         };
 
-                        // Validate the extra.
-                        if let Some(extra) = extra {
-                            if !metadata.provides_extras.contains(extra) {
-                                diagnostics.push(ResolutionDiagnostic::MissingExtra {
-                                    dist: dist.clone().into(),
-                                    extra: extra.clone(),
-                                });
-                            }
-                        }
-                        // Extract the markers.
-                        let marker = markers.get(&(name, version, extra)).cloned();
+                        archive.metadata.clone()
+                    };
 
-                        // Add the distribution to the graph.
-                        let index = petgraph.add_node(AnnotatedDist {
-                            dist: dist.into(),
-                            extra: extra.clone(),
-                            marker,
-                            hashes,
-                            metadata,
-                        });
-                        inverse.insert((name, version, extra), index);
-                    }
-
-                    _ => {}
+                    (dist, hashes, metadata)
                 };
+
+                // Validate the extra.
+                if let Some(extra) = extra {
+                    if !metadata.provides_extras.contains(extra) {
+                        diagnostics.push(ResolutionDiagnostic::MissingExtra {
+                            dist: dist.clone(),
+                            extra: extra.clone(),
+                        });
+                    }
+                }
+
+                // Validate the development dependency group.
+                if let Some(dev) = dev {
+                    if !metadata.dev_dependencies.contains_key(dev) {
+                        diagnostics.push(ResolutionDiagnostic::MissingDev {
+                            dist: dist.clone(),
+                            dev: dev.clone(),
+                        });
+                    }
+                }
+
+                // Add the distribution to the graph.
+                let index = petgraph.add_node(AnnotatedDist {
+                    dist,
+                    extra: extra.clone(),
+                    dev: dev.clone(),
+                    hashes,
+                    metadata,
+                });
+                inverse.insert((name, version, extra.as_ref(), dev.as_ref()), index);
             }
         }
 
         // Add every edge to the graph.
         for (names, version_set) in resolution.dependencies {
             for versions in version_set {
-                let from_index =
-                    inverse[&(&names.from, &versions.from_version, &versions.from_extra)];
-                let to_index = inverse[&(&names.to, &versions.to_version, &versions.to_extra)];
-                petgraph.update_edge(from_index, to_index, versions.to_version.clone());
+                let from_index = inverse[&(
+                    &names.from,
+                    &versions.from_version,
+                    versions.from_extra.as_ref(),
+                    versions.from_dev.as_ref(),
+                )];
+                let to_index = inverse[&(
+                    &names.to,
+                    &versions.to_version,
+                    versions.to_extra.as_ref(),
+                    versions.to_dev.as_ref(),
+                )];
+
+                if let Some(edge) = petgraph
+                    .find_edge(from_index, to_index)
+                    .and_then(|edge| petgraph.edge_weight_mut(edge))
+                {
+                    // If either the existing marker or new marker is `None`, then the dependency is
+                    // included unconditionally, and so the combined marker should be `None`.
+                    if let (Some(marker), Some(ref version_marker)) =
+                        (edge.as_mut(), versions.marker)
+                    {
+                        marker.or(version_marker.clone());
+                    } else {
+                        *edge = None;
+                    }
+                } else {
+                    petgraph.update_edge(from_index, to_index, versions.marker.clone());
+                }
             }
         }
 
+        // Extract the `Requires-Python` range, if provided.
+        // TODO(charlie): Infer the supported Python range from the `Requires-Python` of the
+        // included packages.
+        let requires_python = python
+            .target()
+            .and_then(PythonTarget::as_requires_python)
+            .cloned();
+
         Ok(Self {
             petgraph,
+            requires_python,
             diagnostics,
         })
     }
@@ -281,7 +285,7 @@ impl ResolutionGraph {
         self.petgraph
             .node_indices()
             .map(|index| &self.petgraph[index])
-            .filter(|dist| dist.extra.is_none())
+            .filter(|dist| dist.is_base())
             .count()
     }
 
@@ -393,14 +397,7 @@ impl ResolutionGraph {
                     dist.version_id()
                 )
             };
-            let requirements: Vec<_> = archive
-                .metadata
-                .requires_dist
-                .iter()
-                .cloned()
-                .map(Requirement::from)
-                .collect();
-            for req in manifest.apply(requirements.iter()) {
+            for req in manifest.apply(archive.metadata.requires_dist.iter()) {
                 let Some(ref marker_tree) = req.marker else {
                     continue;
                 };
@@ -441,21 +438,6 @@ impl ResolutionGraph {
         }
         Ok(MarkerTree::And(conjuncts))
     }
-
-    pub fn lock(&self) -> anyhow::Result<Lock, LockError> {
-        let mut locked_dists = vec![];
-        for node_index in self.petgraph.node_indices() {
-            let dist = &self.petgraph[node_index];
-            let mut locked_dist = lock::Distribution::from_annotated_dist(dist)?;
-            for neighbor in self.petgraph.neighbors(node_index) {
-                let dependency_dist = &self.petgraph[neighbor];
-                locked_dist.add_dependency(dependency_dist);
-            }
-            locked_dists.push(locked_dist);
-        }
-        let lock = Lock::new(locked_dists)?;
-        Ok(lock)
-    }
 }
 
 impl From<ResolutionGraph> for distribution_types::Resolution {
