@@ -8,7 +8,8 @@ use tracing::instrument;
 use distribution_filename::{DistFilename, WheelFilename};
 use distribution_types::{
     HashComparison, IncompatibleSource, IncompatibleWheel, IndexUrl, PrioritizedDist,
-    RegistryBuiltWheel, RegistrySourceDist, SourceDistCompatibility, WheelCompatibility,
+    PythonRequirementKind, RegistryBuiltWheel, RegistrySourceDist, SourceDistCompatibility,
+    WheelCompatibility,
 };
 use pep440_rs::{Version, VersionSpecifiers};
 use platform_tags::{TagCompatibility, Tags};
@@ -44,7 +45,7 @@ impl VersionMap {
         simple_metadata: OwnedArchive<SimpleMetadata>,
         package_name: &PackageName,
         index: &IndexUrl,
-        tags: &Tags,
+        tags: Option<&Tags>,
         python_requirement: &PythonRequirement,
         allowed_yanks: &AllowedYanks,
         hasher: &HashStrategy,
@@ -119,7 +120,7 @@ impl VersionMap {
                 no_binary,
                 no_build,
                 index: index.clone(),
-                tags: tags.clone(),
+                tags: tags.cloned(),
                 python_requirement: python_requirement.clone(),
                 exclude_newer: exclude_newer.copied(),
                 allowed_yanks,
@@ -297,7 +298,7 @@ struct VersionMapLazy {
     index: IndexUrl,
     /// The set of compatibility tags that determines whether a wheel is usable
     /// in the current environment.
-    tags: Tags,
+    tags: Option<Tags>,
     /// The version of Python active in the current environment. This is used
     /// to determine whether a package's Python version constraint (if one
     /// exists) is satisfied or not.
@@ -465,11 +466,20 @@ impl VersionMapLazy {
         // Source distributions must meet both the _target_ Python version and the
         // _installed_ Python version (to build successfully)
         if let Some(requires_python) = requires_python {
-            if !requires_python.contains(self.python_requirement.target())
-                || !requires_python.contains(self.python_requirement.installed())
-            {
+            if let Some(target) = self.python_requirement.target() {
+                if !target.is_compatible_with(&requires_python) {
+                    return SourceDistCompatibility::Incompatible(
+                        IncompatibleSource::RequiresPython(
+                            requires_python,
+                            PythonRequirementKind::Target,
+                        ),
+                    );
+                }
+            }
+            if !requires_python.contains(self.python_requirement.installed()) {
                 return SourceDistCompatibility::Incompatible(IncompatibleSource::RequiresPython(
                     requires_python,
+                    PythonRequirementKind::Installed,
                 ));
             }
         }
@@ -521,21 +531,34 @@ impl VersionMapLazy {
             }
         }
 
-        // Check for a Python version incompatibility`
+        // Check for a Python version incompatibility
         if let Some(requires_python) = requires_python {
-            if !requires_python.contains(self.python_requirement.target()) {
-                return WheelCompatibility::Incompatible(IncompatibleWheel::RequiresPython(
-                    requires_python,
-                ));
+            if let Some(target) = self.python_requirement.target() {
+                if !target.is_compatible_with(&requires_python) {
+                    return WheelCompatibility::Incompatible(IncompatibleWheel::RequiresPython(
+                        requires_python,
+                        PythonRequirementKind::Target,
+                    ));
+                }
+            } else {
+                if !requires_python.contains(self.python_requirement.installed()) {
+                    return WheelCompatibility::Incompatible(IncompatibleWheel::RequiresPython(
+                        requires_python,
+                        PythonRequirementKind::Installed,
+                    ));
+                }
             }
         }
 
         // Determine a compatibility for the wheel based on tags.
-        let priority = match filename.compatibility(&self.tags) {
-            TagCompatibility::Incompatible(tag) => {
-                return WheelCompatibility::Incompatible(IncompatibleWheel::Tag(tag))
-            }
-            TagCompatibility::Compatible(priority) => priority,
+        let priority = match &self.tags {
+            Some(tags) => match filename.compatibility(tags) {
+                TagCompatibility::Incompatible(tag) => {
+                    return WheelCompatibility::Incompatible(IncompatibleWheel::Tag(tag))
+                }
+                TagCompatibility::Compatible(priority) => Some(priority),
+            },
+            None => None,
         };
 
         // Check if hashes line up. If hashes aren't required, they're considered matching.
