@@ -27,6 +27,14 @@ impl Workspace {
         match read_file(&file) {
             Ok(options) => Ok(Some(Self { options, root })),
             Err(WorkspaceError::Io(err)) if err.kind() == std::io::ErrorKind::NotFound => Ok(None),
+            Err(_) if !dir.is_dir() => {
+                // Ex) `XDG_CONFIG_HOME=/dev/null`
+                debug!(
+                    "User configuration directory `{}` does not exist or is not a directory",
+                    dir.display()
+                );
+                Ok(None)
+            }
             Err(err) => Err(err),
         }
     }
@@ -47,9 +55,9 @@ impl Workspace {
                 Ok(None) => {
                     // Continue traversing the directory tree.
                 }
-                Err(err @ WorkspaceError::PyprojectToml(..)) => {
+                Err(WorkspaceError::PyprojectToml(file, err)) => {
                     // If we see an invalid `pyproject.toml`, warn but continue.
-                    warn_user!("{err}");
+                    warn_user!("Failed to parse `{file}`: {err}");
                 }
                 Err(err) => {
                     // Otherwise, warn and stop.
