@@ -153,6 +153,12 @@ pub(crate) enum Commands {
     /// Resolve the project requirements into a lockfile.
     #[clap(hide = true)]
     Lock(LockArgs),
+    /// Add one or more packages to the project requirements.
+    #[clap(hide = true)]
+    Add(AddArgs),
+    /// Remove one or more packages from the project requirements.
+    #[clap(hide = true)]
+    Remove(RemoveArgs),
     /// Display uv's version
     Version {
         #[arg(long, value_enum, default_value = "text")]
@@ -1655,6 +1661,9 @@ pub(crate) struct VenvArgs {
 
     /// The URL of the Python package index (by default: <https://pypi.org/simple>).
     ///
+    /// Accepts either a repository compliant with PEP 503 (the simple repository API), or a local
+    /// directory laid out in the same format.
+    ///
     /// The index given by this flag is given lower priority than all other
     /// indexes specified via the `--extra-index-url` flag.
     ///
@@ -1666,6 +1675,9 @@ pub(crate) struct VenvArgs {
 
     /// Extra URLs of package indexes to use, in addition to `--index-url`.
     ///
+    /// Accepts either a repository compliant with PEP 503 (the simple repository API), or a local
+    /// directory laid out in the same format.
+    ///
     /// All indexes given via this flag take priority over the index
     /// in `--index-url` (which defaults to PyPI). And when multiple
     /// `--extra-index-url` flags are given, earlier values take priority.
@@ -1916,16 +1928,48 @@ pub(crate) struct LockArgs {
 
 #[derive(Args)]
 #[allow(clippy::struct_excessive_bools)]
-struct AddArgs {
-    /// The name of the package to add (e.g., `Django==4.2.6`).
-    name: String,
+pub(crate) struct AddArgs {
+    /// The packages to remove, as PEP 508 requirements (e.g., `flask==2.2.3`).
+    #[arg(required = true)]
+    pub(crate) requirements: Vec<String>,
+
+    /// The Python interpreter into which packages should be installed.
+    ///
+    /// By default, `uv` installs into the virtual environment in the current working directory or
+    /// any parent directory. The `--python` option allows you to specify a different interpreter,
+    /// which is intended for use in continuous integration (CI) environments or other automated
+    /// workflows.
+    ///
+    /// Supported formats:
+    /// - `3.10` looks for an installed Python 3.10 using `py --list-paths` on Windows, or
+    ///   `python3.10` on Linux and macOS.
+    /// - `python3.10` or `python.exe` looks for a binary with the given name in `PATH`.
+    /// - `/home/ferris/.local/bin/python3.10` uses the exact Python at the given path.
+    #[arg(long, short, env = "UV_PYTHON", verbatim_doc_comment)]
+    pub(crate) python: Option<String>,
 }
 
 #[derive(Args)]
 #[allow(clippy::struct_excessive_bools)]
-struct RemoveArgs {
-    /// The name of the package to remove (e.g., `Django`).
-    name: PackageName,
+pub(crate) struct RemoveArgs {
+    /// The names of the packages to remove (e.g., `flask`).
+    #[arg(required = true)]
+    pub(crate) requirements: Vec<PackageName>,
+
+    /// The Python interpreter into which packages should be installed.
+    ///
+    /// By default, `uv` installs into the virtual environment in the current working directory or
+    /// any parent directory. The `--python` option allows you to specify a different interpreter,
+    /// which is intended for use in continuous integration (CI) environments or other automated
+    /// workflows.
+    ///
+    /// Supported formats:
+    /// - `3.10` looks for an installed Python 3.10 using `py --list-paths` on Windows, or
+    ///   `python3.10` on Linux and macOS.
+    /// - `python3.10` or `python.exe` looks for a binary with the given name in `PATH`.
+    /// - `/home/ferris/.local/bin/python3.10` uses the exact Python at the given path.
+    #[arg(long, short, env = "UV_PYTHON", verbatim_doc_comment)]
+    pub(crate) python: Option<String>,
 }
 
 #[derive(Args)]
@@ -2008,7 +2052,7 @@ pub(crate) struct ToolchainListArgs {
 #[derive(Args)]
 #[allow(clippy::struct_excessive_bools)]
 pub(crate) struct ToolchainInstallArgs {
-    /// The toolchain to fetch.
+    /// The toolchain to install.
     ///
     /// If not provided, the latest available version will be installed.
     pub(crate) target: Option<String>,
@@ -2018,6 +2062,9 @@ pub(crate) struct ToolchainInstallArgs {
 pub(crate) struct IndexArgs {
     /// The URL of the Python package index (by default: <https://pypi.org/simple>).
     ///
+    /// Accepts either a repository compliant with PEP 503 (the simple repository API), or a local
+    /// directory laid out in the same format.
+    ///
     /// The index given by this flag is given lower priority than all other
     /// indexes specified via the `--extra-index-url` flag.
     ///
@@ -2029,6 +2076,9 @@ pub(crate) struct IndexArgs {
 
     /// Extra URLs of package indexes to use, in addition to `--index-url`.
     ///
+    /// Accepts either a repository compliant with PEP 503 (the simple repository API), or a local
+    /// directory laid out in the same format.
+    ///
     /// All indexes given via this flag take priority over the index
     /// in `--index-url` (which defaults to PyPI). And when multiple
     /// `--extra-index-url` flags are given, earlier values take priority.
