@@ -1,4 +1,3 @@
-use std::borrow::Cow;
 use std::env;
 use std::fmt::Write;
 use std::io::stdout;
@@ -18,7 +17,6 @@ use distribution_types::{
     Verbatim,
 };
 use install_wheel_rs::linker::LinkMode;
-use platform_tags::Tags;
 use uv_auth::store_credentials_from_url;
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
@@ -31,11 +29,6 @@ use uv_dispatch::BuildDispatch;
 use uv_distribution::DistributionDatabase;
 use uv_fs::Simplified;
 use uv_git::GitResolver;
-use uv_interpreter::{
-    find_best_interpreter, find_interpreter, InterpreterRequest, PythonEnvironment, SystemPython,
-    VersionRequest,
-};
-use uv_interpreter::{PythonVersion, SourceSelector};
 use uv_normalize::{ExtraName, PackageName};
 use uv_requirements::{
     upgrade::read_requirements_txt, LookaheadResolver, NamedRequirementsResolver,
@@ -46,10 +39,13 @@ use uv_resolver::{
     InMemoryIndex, Manifest, OptionsBuilder, PreReleaseMode, PythonRequirement, ResolutionMode,
     Resolver,
 };
+use uv_toolchain::{
+    PythonEnvironment, PythonVersion, SystemPython, Toolchain, ToolchainRequest, VersionRequest,
+};
 use uv_types::{BuildIsolation, EmptyInstalledPackages, HashStrategy, InFlight};
 use uv_warnings::warn_user;
 
-use crate::commands::pip::operations;
+use crate::commands::pip::{operations, resolution_environment};
 use crate::commands::reporters::ResolverReporter;
 use crate::commands::{elapsed, ExitStatus};
 use crate::printer::Printer;
@@ -163,18 +159,19 @@ pub(crate) async fn pip_compile(
         SystemPython::Allowed
     };
     let interpreter = if let Some(python) = python.as_ref() {
-        let request = InterpreterRequest::parse(python);
-        let sources = SourceSelector::from_settings(system, preview);
-        find_interpreter(&request, system, &sources, &cache)??
+        let request = ToolchainRequest::parse(python);
+        Toolchain::find_requested(&request, system, preview, &cache)
     } else {
+        // TODO(zanieb): The split here hints at a problem with the abstraction; we should be able to use
+        // `Toolchain::find(...)` here.
         let request = if let Some(version) = python_version.as_ref() {
             // TODO(zanieb): We should consolidate `VersionRequest` and `PythonVersion`
-            InterpreterRequest::Version(VersionRequest::from(version))
+            ToolchainRequest::Version(VersionRequest::from(version))
         } else {
-            InterpreterRequest::default()
+            ToolchainRequest::default()
         };
-        find_best_interpreter(&request, system, preview, &cache)??
-    }
+        Toolchain::find_best(&request, system, preview, &cache)
+    }?
     .into_interpreter();
 
     debug!(
@@ -222,41 +219,8 @@ pub(crate) async fn pip_compile(
         PythonRequirement::from_interpreter(&interpreter)
     };
 
-    // Determine the tags, markers, and interpreter to use for resolution.
-    let tags = match (python_platform, python_version.as_ref()) {
-        (Some(python_platform), Some(python_version)) => Cow::Owned(Tags::from_env(
-            &python_platform.platform(),
-            (python_version.major(), python_version.minor()),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (Some(python_platform), None) => Cow::Owned(Tags::from_env(
-            &python_platform.platform(),
-            interpreter.python_tuple(),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (None, Some(python_version)) => Cow::Owned(Tags::from_env(
-            interpreter.platform(),
-            (python_version.major(), python_version.minor()),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (None, None) => Cow::Borrowed(interpreter.tags()?),
-    };
-
-    // Apply the platform tags to the markers.
-    let markers = match (python_platform, python_version) {
-        (Some(python_platform), Some(python_version)) => {
-            Cow::Owned(python_version.markers(&python_platform.markers(interpreter.markers())))
-        }
-        (Some(python_platform), None) => Cow::Owned(python_platform.markers(interpreter.markers())),
-        (None, Some(python_version)) => Cow::Owned(python_version.markers(interpreter.markers())),
-        (None, None) => Cow::Borrowed(interpreter.markers()),
-    };
+    // Determine the environment for the resolution.
+    let (tags, markers) = resolution_environment(python_version, python_platform, &interpreter)?;
 
     // Generate, but don't enforce hashes for the requirements.
     let hasher = if generate_hashes {
@@ -293,17 +257,17 @@ pub(crate) async fn pip_compile(
     let flat_index = {
         let client = FlatIndexClient::new(&client, &cache);
         let entries = client.fetch(index_locations.flat_index()).await?;
-        FlatIndex::from_entries(entries, &tags, &hasher, &no_build, &NoBinary::None)
+        FlatIndex::from_entries(entries, Some(&tags), &hasher, &no_build, &NoBinary::None)
     };
 
     // Track in-flight downloads, builds, etc., across resolutions.
     let in_flight = InFlight::default();
 
     // Determine whether to enable build isolation.
-    let venv;
+    let environment;
     let build_isolation = if no_build_isolation {
-        venv = PythonEnvironment::from_interpreter(interpreter.clone());
-        BuildIsolation::Shared(&venv)
+        environment = PythonEnvironment::from_interpreter(interpreter.clone());
+        BuildIsolation::Shared(&environment)
     } else {
         BuildIsolation::Isolated
     };
@@ -473,6 +437,7 @@ pub(crate) async fn pip_compile(
                 &requirements,
                 &constraints,
                 &overrides,
+                &dev,
                 &hasher,
                 &top_level_index,
                 DistributionDatabase::new(&client, &build_dispatch, concurrency.downloads, preview),
@@ -511,7 +476,7 @@ pub(crate) async fn pip_compile(
         options,
         &python_requirement,
         Some(&markers),
-        &tags,
+        Some(&tags),
         &flat_index,
         &top_level_index,
         &hasher,
