@@ -15,15 +15,15 @@ use uv_configuration::{
     Concurrency, ConfigSettings, ExtrasSpecification, IndexStrategy, KeyringProviderType, NoBinary,
     NoBuild, PreviewMode, Reinstall, SetupPyStrategy, TargetTriple, Upgrade,
 };
-use uv_interpreter::{PythonVersion, Target};
 use uv_normalize::PackageName;
 use uv_resolver::{AnnotationStyle, DependencyMode, ExcludeNewer, PreReleaseMode, ResolutionMode};
+use uv_toolchain::{Prefix, PythonVersion, Target};
 use uv_workspace::{Combine, PipOptions, Workspace};
 
 use crate::cli::{
-    ColorChoice, GlobalArgs, LockArgs, Maybe, PipCheckArgs, PipCompileArgs, PipFreezeArgs,
-    PipInstallArgs, PipListArgs, PipShowArgs, PipSyncArgs, PipUninstallArgs, RunArgs, SyncArgs,
-    ToolRunArgs, VenvArgs,
+    AddArgs, ColorChoice, GlobalArgs, LockArgs, Maybe, PipCheckArgs, PipCompileArgs, PipFreezeArgs,
+    PipInstallArgs, PipListArgs, PipShowArgs, PipSyncArgs, PipUninstallArgs, RemoveArgs, RunArgs,
+    SyncArgs, ToolRunArgs, ToolchainInstallArgs, ToolchainListArgs, VenvArgs,
 };
 use crate::commands::ListFormat;
 
@@ -113,6 +113,7 @@ impl CacheSettings {
 pub(crate) struct RunSettings {
     pub(crate) index_locations: IndexLocations,
     pub(crate) extras: ExtrasSpecification,
+    pub(crate) dev: bool,
     pub(crate) target: Option<String>,
     pub(crate) args: Vec<OsString>,
     pub(crate) with: Vec<String>,
@@ -131,6 +132,8 @@ impl RunSettings {
             extra,
             all_extras,
             no_all_extras,
+            dev,
+            no_dev,
             target,
             args,
             with,
@@ -140,7 +143,6 @@ impl RunSettings {
             upgrade,
             no_upgrade,
             upgrade_package,
-
             index_args,
             python,
             exclude_newer,
@@ -168,6 +170,7 @@ impl RunSettings {
                 flag(all_extras, no_all_extras).unwrap_or_default(),
                 extra.unwrap_or_default(),
             ),
+            dev: flag(dev, no_dev).unwrap_or(true),
             target,
             args,
             with,
@@ -227,6 +230,59 @@ impl ToolRunSettings {
     }
 }
 
+#[derive(Debug, Clone, Default)]
+pub(crate) enum ToolchainListIncludes {
+    #[default]
+    Default,
+    All,
+    Installed,
+}
+
+/// The resolved settings to use for a `tool run` invocation.
+#[allow(clippy::struct_excessive_bools)]
+#[derive(Debug, Clone)]
+pub(crate) struct ToolchainListSettings {
+    pub(crate) includes: ToolchainListIncludes,
+}
+
+impl ToolchainListSettings {
+    /// Resolve the [`ToolchainListSettings`] from the CLI and workspace configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: ToolchainListArgs, _workspace: Option<Workspace>) -> Self {
+        let ToolchainListArgs {
+            all,
+            only_installed,
+        } = args;
+
+        let includes = if all {
+            ToolchainListIncludes::All
+        } else if only_installed {
+            ToolchainListIncludes::Installed
+        } else {
+            ToolchainListIncludes::default()
+        };
+
+        Self { includes }
+    }
+}
+
+/// The resolved settings to use for a `toolchain install` invocation.
+#[allow(clippy::struct_excessive_bools)]
+#[derive(Debug, Clone)]
+pub(crate) struct ToolchainInstallSettings {
+    pub(crate) target: Option<String>,
+}
+
+impl ToolchainInstallSettings {
+    /// Resolve the [`ToolchainInstallSettings`] from the CLI and workspace configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: ToolchainInstallArgs, _workspace: Option<Workspace>) -> Self {
+        let ToolchainInstallArgs { target } = args;
+
+        Self { target }
+    }
+}
+
 /// The resolved settings to use for a `sync` invocation.
 #[allow(clippy::struct_excessive_bools, dead_code)]
 #[derive(Debug, Clone)]
@@ -234,6 +290,7 @@ pub(crate) struct SyncSettings {
     pub(crate) index_locations: IndexLocations,
     pub(crate) refresh: Refresh,
     pub(crate) extras: ExtrasSpecification,
+    pub(crate) dev: bool,
     pub(crate) python: Option<String>,
 }
 
@@ -245,6 +302,8 @@ impl SyncSettings {
             extra,
             all_extras,
             no_all_extras,
+            dev,
+            no_dev,
             refresh,
             no_refresh,
             refresh_package,
@@ -272,6 +331,7 @@ impl SyncSettings {
                 flag(all_extras, no_all_extras).unwrap_or_default(),
                 extra.unwrap_or_default(),
             ),
+            dev: flag(dev, no_dev).unwrap_or(true),
             python,
         }
     }
@@ -327,6 +387,54 @@ impl LockSettings {
     }
 }
 
+/// The resolved settings to use for a `add` invocation.
+#[allow(clippy::struct_excessive_bools, dead_code)]
+#[derive(Debug, Clone)]
+pub(crate) struct AddSettings {
+    pub(crate) requirements: Vec<String>,
+    pub(crate) python: Option<String>,
+}
+
+impl AddSettings {
+    /// Resolve the [`AddSettings`] from the CLI and workspace configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: AddArgs, _workspace: Option<Workspace>) -> Self {
+        let AddArgs {
+            requirements,
+            python,
+        } = args;
+
+        Self {
+            requirements,
+            python,
+        }
+    }
+}
+
+/// The resolved settings to use for a `remove` invocation.
+#[allow(clippy::struct_excessive_bools, dead_code)]
+#[derive(Debug, Clone)]
+pub(crate) struct RemoveSettings {
+    pub(crate) requirements: Vec<PackageName>,
+    pub(crate) python: Option<String>,
+}
+
+impl RemoveSettings {
+    /// Resolve the [`RemoveSettings`] from the CLI and workspace configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: RemoveArgs, _workspace: Option<Workspace>) -> Self {
+        let RemoveArgs {
+            requirements,
+            python,
+        } = args;
+
+        Self {
+            requirements,
+            python,
+        }
+    }
+}
+
 /// The resolved settings to use for a `pip compile` invocation.
 #[allow(clippy::struct_excessive_bools)]
 #[derive(Debug, Clone)]
@@ -438,7 +546,6 @@ impl PipCompileSettings {
                 PipOptions {
                     python,
                     system: flag(system, no_system),
-
                     index_url: index_args.index_url.and_then(Maybe::into_option),
                     extra_index_url: index_args.extra_index_url.map(|extra_index_urls| {
                         extra_index_urls
@@ -532,6 +639,7 @@ impl PipSyncSettings {
             break_system_packages,
             no_break_system_packages,
             target,
+            prefix,
             legacy_setup_py,
             no_legacy_setup_py,
             no_build_isolation,
@@ -570,6 +678,7 @@ impl PipSyncSettings {
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
                     target,
+                    prefix,
                     index_url: index_args.index_url.and_then(Maybe::into_option),
                     extra_index_url: index_args.extra_index_url.map(|extra_index_urls| {
                         extra_index_urls
@@ -665,6 +774,7 @@ impl PipInstallSettings {
             break_system_packages,
             no_break_system_packages,
             target,
+            prefix,
             legacy_setup_py,
             no_legacy_setup_py,
             no_build_isolation,
@@ -723,6 +833,7 @@ impl PipInstallSettings {
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
                     target,
+                    prefix,
                     index_url: index_args.index_url.and_then(Maybe::into_option),
                     extra_index_url: index_args.extra_index_url.map(|extra_index_urls| {
                         extra_index_urls
@@ -793,6 +904,7 @@ impl PipUninstallSettings {
             break_system_packages,
             no_break_system_packages,
             target,
+            prefix,
         } = args;
 
         Self {
@@ -807,7 +919,7 @@ impl PipUninstallSettings {
                     system: flag(system, no_system),
                     break_system_packages: flag(break_system_packages, no_break_system_packages),
                     target,
-
+                    prefix,
                     keyring_provider,
                     ..PipOptions::default()
                 },
@@ -1066,6 +1178,7 @@ pub(crate) struct PipSharedSettings {
     pub(crate) extras: ExtrasSpecification,
     pub(crate) break_system_packages: bool,
     pub(crate) target: Option<Target>,
+    pub(crate) prefix: Option<Prefix>,
     pub(crate) index_strategy: IndexStrategy,
     pub(crate) keyring_provider: KeyringProviderType,
     pub(crate) no_binary: NoBinary,
@@ -1106,6 +1219,7 @@ impl PipSharedSettings {
             system,
             break_system_packages,
             target,
+            prefix,
             index_url,
             extra_index_url,
             no_index,
@@ -1249,6 +1363,7 @@ impl PipSharedSettings {
                 .combine(break_system_packages)
                 .unwrap_or_default(),
             target: args.target.combine(target).map(Target::from),
+            prefix: args.prefix.combine(prefix).map(Prefix::from),
             no_binary: NoBinary::from_args(args.no_binary.combine(no_binary).unwrap_or_default()),
             compile_bytecode: args
                 .compile_bytecode
