@@ -45,6 +45,12 @@ pub const INSTA_FILTERS: &[(&str, &str)] = &[
     ),
 ];
 
+/// Create a context for tests which simplfiies shared behavior across tests.
+///
+/// * Set the current directory to a temporary directory (`temp_dir`).
+/// * Set the cache dir to a different temporary directory (`cache_dir`).
+/// * Set a cutoff for versions used in the resolution so the snapshots don't change after a new release.
+/// * Set the venv to a fresh `.venv` in `temp_dir`.
 #[derive(Debug)]
 pub struct TestContext {
     pub temp_dir: assert_fs::TempDir,
@@ -153,11 +159,7 @@ impl TestContext {
         }
     }
 
-    /// Set shared defaults between tests:
-    /// * Set the current directory to a temporary directory (`temp_dir`).
-    /// * Set the cache dir to a different temporary directory (`cache_dir`).
-    /// * Set a cutoff for versions used in the resolution so the snapshots don't change after a new release.
-    /// * Set the venv to a fresh `.venv` in `temp_dir`.
+    /// Create a `pip compile` command for testing.
     pub fn compile(&self) -> std::process::Command {
         let mut command = self.compile_without_exclude_newer();
         command.arg("--exclude-newer").arg(EXCLUDE_NEWER);
@@ -178,6 +180,7 @@ impl TestContext {
             .arg(self.cache_dir.path())
             .env("VIRTUAL_ENV", self.venv.as_os_str())
             .env("UV_NO_WRAP", "1")
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
             .current_dir(self.temp_dir.path());
 
         if cfg!(all(windows, debug_assertions)) {
@@ -211,6 +214,7 @@ impl TestContext {
             .arg(self.cache_dir.path())
             .env("VIRTUAL_ENV", self.venv.as_os_str())
             .env("UV_NO_WRAP", "1")
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
             .current_dir(&self.temp_dir);
 
         if cfg!(all(windows, debug_assertions)) {
@@ -230,7 +234,9 @@ impl TestContext {
             .arg("--cache-dir")
             .arg(self.cache_dir.path())
             .env("VIRTUAL_ENV", self.venv.as_os_str())
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
             .env("UV_NO_WRAP", "1")
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
             .current_dir(&self.temp_dir);
 
         if cfg!(all(windows, debug_assertions)) {
@@ -245,7 +251,10 @@ impl TestContext {
     /// Create a `uv lock` command with options shared across scenarios.
     pub fn lock(&self) -> std::process::Command {
         let mut command = self.lock_without_exclude_newer();
-        command.arg("--exclude-newer").arg(EXCLUDE_NEWER);
+        command
+            .arg("--exclude-newer")
+            .arg(EXCLUDE_NEWER)
+            .env("UV_TEST_PYTHON_PATH", "/dev/null");
         command
     }
 
@@ -263,6 +272,7 @@ impl TestContext {
             .arg(self.cache_dir.path())
             .env("VIRTUAL_ENV", self.venv.as_os_str())
             .env("UV_NO_WRAP", "1")
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
             .current_dir(&self.temp_dir);
 
         if cfg!(all(windows, debug_assertions)) {
@@ -295,6 +305,49 @@ impl TestContext {
             .arg(self.cache_dir.path())
             .env("VIRTUAL_ENV", self.venv.as_os_str())
             .env("UV_NO_WRAP", "1")
+            .env("UV_TEST_PYTHON_PATH", "/dev/null")
+            .current_dir(&self.temp_dir);
+
+        if cfg!(all(windows, debug_assertions)) {
+            // TODO(konstin): Reduce stack usage in debug mode enough that the tests pass with the
+            // default windows stack of 1MB
+            command.env("UV_STACK_SIZE", (4 * 1024 * 1024).to_string());
+        }
+
+        command
+    }
+
+    /// Create a `uv add` command for the given requirements.
+    pub fn add(&self, reqs: &[&str]) -> std::process::Command {
+        let mut command = std::process::Command::new(get_bin());
+        command
+            .arg("add")
+            .args(reqs)
+            .arg("--cache-dir")
+            .arg(self.cache_dir.path())
+            .env("VIRTUAL_ENV", self.venv.as_os_str())
+            .env("UV_NO_WRAP", "1")
+            .current_dir(&self.temp_dir);
+
+        if cfg!(all(windows, debug_assertions)) {
+            // TODO(konstin): Reduce stack usage in debug mode enough that the tests pass with the
+            // default windows stack of 1MB
+            command.env("UV_STACK_SIZE", (4 * 1024 * 1024).to_string());
+        }
+
+        command
+    }
+
+    /// Create a `uv remove` command for the given requirements.
+    pub fn remove(&self, reqs: &[&str]) -> std::process::Command {
+        let mut command = std::process::Command::new(get_bin());
+        command
+            .arg("remove")
+            .args(reqs)
+            .arg("--cache-dir")
+            .arg(self.cache_dir.path())
+            .env("VIRTUAL_ENV", self.venv.as_os_str())
+            .env("UV_NO_WRAP", "1")
             .current_dir(&self.temp_dir);
 
         if cfg!(all(windows, debug_assertions)) {
